Visual working memory — BCI-Framework documentation

# Visual working memory

Implemented through extensions systems in the VisualWorkingMemory module.

The task consists in remembering the colors of a set of squares displayed on a computer screen, termed memory array, and then comparing them with the colors of a second set of squares located in the same positions, termed test array 1. A trial of the task begins with an arrow indicating either the left or the right side of the screen for 0.2 s. Then, a memory array appears on the screen for 0.1 s. For every trial, memory arrays are displayed on both hemifields, but the subject must remember only those appearing on the side indicated by the arrow cue. Next, after a retention interval lasting 0.9 s, a test array appears for a period of 2 s. During this period the subject reports if the colors of all the items in the memory and test arrays match. The task has three levels according to the number of elements in the memory array: low memory load (one square), medium memory load (two squares), and high memory load (four squares). The subject must perform a total of 300 trials, with 100 trials for each memory load level (50 trials per hemifield). Trials from different levels are presented at random. The color of one of the squares in the test array differs from its counterpart in the memory array in 50% of the trials.

## Stimuli presentation

All stimuli are presented on a computer screen situated 120 cm away from the subject. The stimulus arrays appear within two \(7.2^{\circ}\) × \(13.15^{\circ}\) rectangular regions that are centered \(5.4^{\circ}\) to the left and right of a central fixation cross on a gray background (the symbol \(\circ\) stands for degrees of visual angle 2). Each colored square (\(1.17^{\circ}\) × \(1.17^{\circ}\)) is randomly selected from a set of seven colors (red, blue, violet, green, yellow, black and white). A given color can appear no more than twice within an array. Stimulus positions were randomized on each trial, with the constraint that the distance between squares within a hemifield was at least \(3.5^{\circ}\) (center to center) 3.

## Configuration options

### Squares

Squares size:
Define the size in degrees of visual angle, \(1.17^{\circ}\) by default.
Minimum distance between Squares:
Define the minimum distance between squares in degrees of visual angle, \(3.5^{\circ}\) by default.

### Intervals

Inter trial break:
Break in milliseconds between trials. 2000 ms by default.
Arrow cue:
Time on screen for the cue in milliseconds. 200 ms by default.
Memory array:
Time used to visualize the array. 100 ms by default.
Retention interval:
Time used to memorize the array. 900 ms by default.
Test array:
Time used for the subject to response. 2000 ms by default.

### Trial

Task level:
The level means how many squares will be visible at time.
Numbers of trials per level:
How many trials per class will contain the run. Between 1 and 500, 100 by default.

### Presentation

Distance from monitor:
Used to calculate correctly the DVA units.
Monitor DPI:
The real monitor DPI, used to calculate correctly the DVA units.

### References

1

  Edward K Vogel and Maro G Machizawa. Neural activity predicts individual differences in visual working memory capacity. Nature, 428(6984):748–751, 2004.

2

  LR Newsome. Visual angle and apparent size of objects in peripheral vision. Perception & Psychophysics, 12(3):300–304, 1972.

3

  Mario Villena-González, Iván Rubio-Venegas, and Vladimir López. Data from brain activity during visual working memory replicates the correlation between contralateral delay activity and memory capacity. Data in brief, 28:105042, 2020.